I recommend installing via [uv](https://docs.astral.sh/uv/)!

```
uv add sklx
```

This should be all you need to run in your project to add the package as a dependency!

## pip

You should also be able to install via pip too!

```
python -m pip install sklx
```
